==> xd3d-8.2.3.tar.gz: xd3d-8.2.3/src/d3d/elimin2.f <==
      SUBROUTINE ELIMIN2
C
      INCLUDE 'com_coor.f'
      INCLUDE 'com_faces.f'
      INCLUDE 'com_options.f'
C
      ELEMENTS = 'Quadrangles 3D'
      LELEM    = 14
      IVOL   = 0
      MODTET = 0
      ICOIN  = 0
      NFACE = (NUMX-1)*(NUMY-1)*NUMSD
      IF (NFACE.GT.NFMAX) CALL TROPDEPOINTS(NFACE,-1,0)
      NF = 0
      DO I=1,NFACE
        DO J=1,4
          NBOR(J,I) = 1
        ENDDO
      ENDDO
      DO K=1,NUMSD
        NNN = (K-1)*NUMX*NUMY
        DO J=1,NUMY-1
          DO I=1,NUMX-1
            NF = NF+1
            ISD2(NF) = K
            N1 = (J-1)*NUMX + I
            N2 = N1 + 1
            N3 = N2 + NUMX
            N4 = N3 - 1
            NN1 = N1+NNN
            NN2 = N2+NNN
            NN3 = N3+NNN
            NN4 = N4+NNN
            NFAC(1,NF) = NN1
            NFAC(2,NF) = NN2
            NFAC(3,NF) = NN3
            NFAC(4,NF) = NN4
            NFAC(5,NF) = NUMNP+NF
            NNUMFA(NF) = NF
            NRFAC(NF)  = 0 
            XF(1,NF) = X(N1)
            XF(2,NF) = X(N2)
            XF(3,NF) = X(N3)
            XF(4,NF) = X(N4)
            YF(1,NF) = Y(N1)
            YF(2,NF) = Y(N2)
            YF(3,NF) = Y(N3)
            YF(4,NF) = Y(N4)
            ZF(1,NF) = Z(NN1)
            ZF(2,NF) = Z(NN2)
            ZF(3,NF) = Z(NN3)
            ZF(4,NF) = Z(NN4)
            X(NFAC(5,NF)) = .25*(XF(1,NF)+XF(2,NF)+XF(3,NF)+XF(4,NF))
            Y(NFAC(5,NF)) = .25*(YF(1,NF)+YF(2,NF)+YF(3,NF)+YF(4,NF))
            Z(NFAC(5,NF)) = .25*(ZF(1,NF)+ZF(2,NF)+ZF(3,NF)+ZF(4,NF))
            DEPX(NFAC(5,NF)) = .25*(DEPX(N1)+DEPX(N2)+DEPX(N3)+DEPX(N4))
            DEPY(NFAC(5,NF)) = .25*(DEPY(N1)+DEPY(N2)+DEPY(N3)+DEPY(N4))
            DEPZ(NFAC(5,NF)) = .25*(DEPZ(NN1)+DEPZ(NN2)
     &                             +DEPZ(NN3)+DEPZ(NN4))
            XF(5,NF) = X(NFAC(5,NF))
            YF(5,NF) = Y(NFAC(5,NF))
            ZF(5,NF) = Z(NFAC(5,NF))
            IFPLAN(NF) = 0
            IF (I.EQ.1)        NBOR(4,NF) = 0
            IF (I.EQ.(NUMX-1)) NBOR(2,NF) = 0
            IF (J.EQ.1)        NBOR(1,NF) = 0
            IF (J.EQ.(NUMY-1)) NBOR(3,NF) = 0
          ENDDO
        ENDDO
      ENDDO
      NUMBIS = NUMNP+NF
      NDS = 4
      CALL MINDIAM(NFACE)
C
      END

==> xd3d-8.3.1.tar.gz: xd3d-8.3.1/src/d3d/elimin2.f <==
      SUBROUTINE ELIMIN2
C
      INCLUDE 'com_coor.f'
      INCLUDE 'com_faces.f'
      INCLUDE 'com_options.f'
C
      ELEMENTS = 'Quadrangles 3D'
      LELEM    = 14
      IVOL   = 0
      MODTET = 0
      ICOIN  = 0
      NFACE = (NUMX-1)*(NUMY-1)*NUMSD
      IF (NFACE.GT.NFMAX) CALL TROPDEPOINTS(NFACE,-1,0)
      NF = 0
      DO I=1,NFACE
        DO J=1,4
          NBOR(J,I) = 1
        ENDDO
      ENDDO
      DO K=1,NUMSD
        NNN = (K-1)*NUMX*NUMY
        DO J=1,NUMY-1
          DO I=1,NUMX-1
            NF = NF+1
            ISD2(NF) = K
            N1 = (J-1)*NUMX + I
            N2 = N1 + 1
            N3 = N2 + NUMX
            N4 = N3 - 1
            NN1 = N1+NNN
            NN2 = N2+NNN
            NN3 = N3+NNN
            NN4 = N4+NNN
            NFAC(1,NF) = NN1
            NFAC(2,NF) = NN2
            NFAC(3,NF) = NN3
            NFAC(4,NF) = NN4
            NFAC(5,NF) = NUMNP+NF
            NNUMFA(NF) = NF
            NRFAC(NF)  = 0
            XF(1,NF) = X(N1)
            XF(2,NF) = X(N2)
            XF(3,NF) = X(N3)
            XF(4,NF) = X(N4)
            YF(1,NF) = Y(N1)
            YF(2,NF) = Y(N2)
            YF(3,NF) = Y(N3)
            YF(4,NF) = Y(N4)
            ZF(1,NF) = Z(NN1)
            ZF(2,NF) = Z(NN2)
            ZF(3,NF) = Z(NN3)
            ZF(4,NF) = Z(NN4)
            X(NFAC(5,NF)) = .25*(XF(1,NF)+XF(2,NF)+XF(3,NF)+XF(4,NF))
            Y(NFAC(5,NF)) = .25*(YF(1,NF)+YF(2,NF)+YF(3,NF)+YF(4,NF))
            Z(NFAC(5,NF)) = .25*(ZF(1,NF)+ZF(2,NF)+ZF(3,NF)+ZF(4,NF))
            DEPX(NFAC(5,NF)) = .25*(DEPX(N1)+DEPX(N2)+DEPX(N3)+DEPX(N4))
            DEPY(NFAC(5,NF)) = .25*(DEPY(N1)+DEPY(N2)+DEPY(N3)+DEPY(N4))
            DEPZ(NFAC(5,NF)) = .25*(DEPZ(NN1)+DEPZ(NN2)
     &                             +DEPZ(NN3)+DEPZ(NN4))
            XF(5,NF) = X(NFAC(5,NF))
            YF(5,NF) = Y(NFAC(5,NF))
            ZF(5,NF) = Z(NFAC(5,NF))
            IFPLAN(NF) = 0
            IF (I.EQ.1)        NBOR(4,NF) = 0
            IF (I.EQ.(NUMX-1)) NBOR(2,NF) = 0
            IF (J.EQ.1)        NBOR(1,NF) = 0
            IF (J.EQ.(NUMY-1)) NBOR(3,NF) = 0
          ENDDO
        ENDDO
      ENDDO
      NUMBIS = NUMNP+NF
      NDS = 4
      CALL MINDIAM(NFACE)
C
      END
C-----------------------------------------------------------------------
      SUBROUTINE ELIMIN3
C
      INCLUDE 'com_coor.f'
      INCLUDE 'com_faces.f'
      INCLUDE 'com_options.f'
C
      NDS = 4
      IVOL   = 0
      MODTET = 0
      ICOIN  = 0
      NUMNP8 = NUMNP/8
      NF = 6*NUMNP8
      NEL = NUMNP8
      NFACE = NF
      IF (ILANG.EQ.0) THEN
        ELEMENTS = 'Hexadres 8 noeuds'
      ELSE
        ELEMENTS = 'Hexaedrons 8 nodes'
      ENDIF
      LELEM = 18
      DO I=1,NFACE
        DO J=1,4
          NBOR(J,I) = 1
        ENDDO
        ISD2(I) = 1
        NFAC(5,I) = NUMNP+I
      ENDDO
      DO I=1,NUMNP8
        J = 8*I-7
        K = 6*I-5
        NFAC(1,K) = J
        NFAC(2,K) = J+3
        NFAC(3,K) = J+2
        NFAC(4,K) = J+1
        NFAC(1,K+1) = J+4
        NFAC(2,K+1) = J+5
        NFAC(3,K+1) = J+6
        NFAC(4,K+1) = J+7
        NFAC(1,K+2) = J
        NFAC(2,K+2) = J+1
        NFAC(3,K+2) = J+5
        NFAC(4,K+2) = J+4
        NFAC(1,K+3) = J+3
        NFAC(2,K+3) = J+7
        NFAC(3,K+3) = J+6
        NFAC(4,K+3) = J+2
        NFAC(1,K+4) = J+1
        NFAC(2,K+4) = J+2
        NFAC(3,K+4) = J+6
        NFAC(4,K+4) = J+5
        NFAC(1,K+5) = J
        NFAC(2,K+5) = J+4
        NFAC(3,K+5) = J+7
        NFAC(4,K+5) = J+3
      ENDDO
      DO I=1,NFACE
c         NNUMFA(I) = I
        NNUMFA(I) = 1+(I-1)/6
        NRFAC(I)  = 0
        ISD2(I) = 1
        IFPLAN(I) = 0
        DO J=1,5
          XF(J,I) = X(NFAC(J,I))
          YF(J,I) = Y(NFAC(J,I))
          ZF(J,I) = Z(NFAC(J,I))
        ENDDO
      ENDDO
      NUMBIS = NUMNP+NF
      CALL MINDIAM(NFACE)
      CALL FROETC(1)
C
      END
